@@ -1,25 +1,31 @@
 <?php
-/* startup_folder -- Version 1.0.2 -- setup.php
- * By Scott Heavner
- *
- */
+
+/**
+  * SquirrelMail Startup Folder Plugin
+  * Copyright (C) 2003 Scott Heavner <sdh@po.cwru.edu>
+  * Copyright (C) 2004 Paul Lesneiwski <pdontthink@angrynerds.com>
+  * This program is licensed under GPL. See COPYING for details
+  *
+  */
+
 
 function squirrelmail_plugin_init_startup_folder() {
 
   global $squirrelmail_plugin_hooks;
 
-  $squirrelmail_plugin_hooks['loading_prefs']['startup_folder'] =
+  $squirrelmail_plugin_hooks['webmail_top']['startup_folder'] =
     'startup_folder_override_';
-  $squirrelmail_plugin_hooks['options_folder_inside']['startup_folder'] =
+  $squirrelmail_plugin_hooks['optpage_loadhook_folder']['startup_folder'] =
     'startup_folder_options_';
-  $squirrelmail_plugin_hooks['options_folder_save']['startup_folder'] =
-    'startup_folder_save_';
 }
 
 function startup_folder_version() {
-  return '1.0.2';
+  return '2.0';
 }
 
+if (!defined('SM_PATH'))
+   define('SM_PATH', '../');
+
 function startup_folder_override_() {
   include_once(SM_PATH . 'plugins/startup_folder/functions.php');
   startup_folder_override();
@@ -30,9 +36,4 @@ function startup_folder_options_() {
   startup_folder_options();
 }
 
-function startup_folder_save_() {
-  include_once(SM_PATH . 'plugins/startup_folder/functions.php');
-  startup_folder_save();
-}
-
 ?>
